@@ -447,8 +447,8 @@ class SplunkRemoteSearch(GeneratingCommand):
                 kwargs_oneshot["sample_ratio"] = sample_ratio
 
             # If the search is a raw search but doesn't start with the search keyword, fix this automatically
-            if not re.search("^search\s", searchStr) and not re.search(
-                "^\s{0,}\|", searchStr
+            if not re.search(r"^search\s", searchStr) and not re.search(
+                r"^\s{0,}\|", searchStr
             ):
                 searchStr = f"search {searchStr}"
 
