@@ -43,7 +43,7 @@ logging.getLogger().setLevel(logger.level)
 import trackme_rest_handler
 
 # import trackme libs
-from trackme_libs import trackme_getloglevel
+from trackme_libs import trackme_getloglevel, trackme_get_version
 
 # import trackme licensing libs
 from trackme_libs_licensing import (
@@ -129,14 +129,7 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
         #
 
         # TrackMe version
-        trackme_version = None
-        app_confs = service.confs["app"]
-
-        for stanza in app_confs:
-            if stanza.name == "id":
-                for stanzakey, stanzavalue in stanza.content.items():
-                    if stanzakey == "version":
-                        trackme_version = stanzavalue
+        trackme_version = trackme_get_version(service)
 
         # get the schema_version_required
         schema_version_required = trackme_schema_format_version(trackme_version)
