@@ -389,6 +389,9 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
                 entity_info["splk_dsm_sampling_search"] = entity_searches.get(
                     "splk_dsm_sampling_search"
                 )
+                entity_info["splk_dsm_metrics_populate_search"] = entity_searches.get(
+                    "splk_dsm_metrics_populate_search"
+                )
 
                 # add object and key
                 entity_info["object"] = object_value
