@@ -549,8 +549,18 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
 
                 try:
                     keys_list = resp_dict["keys_list"]
-                    # Handle as a CSV list of keys
-                    keys_list = keys_list.split(",")
+                    # Handle as a CSV list of keys, if not already a list
+                    if not isinstance(keys_list, list):
+                        keys_list = [x.strip() for x in keys_list.split(",") if x.strip()]
+                    else:
+                        # Filter out empty strings from existing list
+                        keys_list = [x.strip() if isinstance(x, str) else x for x in keys_list if (x.strip() if isinstance(x, str) else bool(x))]
+                    # if is empty, return an error
+                    if not keys_list or len(keys_list) == 0:
+                        return {
+                            "payload": "Error: keys_list is required",
+                            "status": 400,
+                        }
                 except Exception as e:
                     return {
                         "payload": "Error: keys_list is required",
