@@ -556,6 +556,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
     def post_wlk_entity_metadata(self, request_info, **kwargs):
         # init
         object_value = None
+        object_id = None
         query_string = None
 
         describe = False
@@ -575,7 +576,32 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
                 describe = False
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
-                object_value = resp_dict["object"]
+                try:
+                    object_value = resp_dict["object"]
+                except Exception as e:
+                    object_value = None
+                try:
+                    object_id = resp_dict["object_id"]
+                except Exception as e:
+                    object_id = None
+                
+                # object or object_id must be provided, but not both
+                if object_value and object_id:
+                    return {
+                        "payload": {
+                            "action": "failure",
+                            "response": "only object or object_id can be specified, not both",
+                        },
+                        "status": 500,
+                    }
+                if not object_value and not object_id:
+                    return {
+                        "payload": {
+                            "action": "failure",
+                            "response": "either object or object_id must be specified",
+                        },
+                        "status": 500,
+                    }
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -589,7 +615,8 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "Tenant identifier",
-                        "object": "The entity identifier",
+                        "object": "The entity identifier, you can specify the object or the object_id, but not both",
+                        "object_id": "The entity key identifier (_key in KVstore), you can specify the object or the object_id, but not both",
                     }
                 ],
             }
@@ -619,9 +646,11 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
         collection = service.kvstore[collection_name]
 
         # Define the KV query
-        query_string = {
-            "object": object_value,
-        }
+        query_string = {}
+        if object_value:
+            query_string["object"] = object_value
+        elif object_id:
+            query_string["_key"] = object_id
 
         # Get the current record
         # Notes: the record is returned as an array, as we search for a specific record, we expect one record only
@@ -629,6 +658,10 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
         try:
             kvrecord = collection.data.query(query=json.dumps(query_string))[0]
             key = kvrecord.get("_key")
+            
+            # If we searched by object_id, get the object value for error messages
+            if not object_value:
+                object_value = kvrecord.get("object")
 
             # get the dict
             json_dict = json.loads(kvrecord.get("version_dict"))
@@ -645,9 +678,10 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
 
         except Exception as e:
             key = None
+            identifier = object_id if object_id else object_value
             return {
                 "payload": {
-                    "response": f'The entity with identifier="{object_value}" was not found, this might be expected in some cases (acceleration searches, etc)',
+                    "response": f'The entity with identifier="{identifier}" was not found, this might be expected in some cases (acceleration searches, etc)',
                 },
                 "status": 404,
             }
