@@ -114,15 +114,6 @@ fields_trackme_general = [
             regex=r"""^[a-zA-Z0-9_\-,]+$""", 
         )
     ), 
-    field.RestField(
-        'allow_admin_operations',
-        required=True,
-        encrypted=False,
-        default='1',
-        validator=validator.Pattern(
-            regex=r"""^(1|0)$""", 
-        )
-    ), 
     field.RestField(
         'enable_conf_manager_receiver',
         required=True,
@@ -298,6 +289,15 @@ fields_trackme_ui_defaults = [
         validator=validator.Pattern(
             regex=r"""^(dark|light)$""", 
         )
+    ), 
+    field.RestField(
+        'auto_refresh',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(1|0)$""", 
+        )
     )
 ]
 model_trackme_ui_defaults = RestModel(fields_trackme_ui_defaults, name='trackme_ui_defaults')
