@@ -96,6 +96,12 @@ from trackme_rest_handler_maintenance_kdb_user import (
 from trackme_rest_handler_maintenance_kdb_admin import (
     TrackMeHandlerMaintenanceKdbAdmin_v2 as handler_maintenance_kdb_admin,
 )
+from trackme_rest_handler_bank_holidays_user import (
+    TrackMeHandlerBankHolidaysRead_v2 as handler_bank_holidays_user,
+)
+from trackme_rest_handler_bank_holidays_admin import (
+    TrackMeHandlerBankHolidaysAdmin_v2 as handler_bank_holidays_admin,
+)
 from trackme_rest_handler_splk_flx_user import (
     TrackMeHandlerSplkFlxTrackingRead_v2 as handler_splk_flx_user,
 )
@@ -408,6 +414,12 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_maintenance_kdb_admin: {
                 "resource_group": "maintenance_kdb/admin",
             },
+            handler_bank_holidays_user: {
+                "resource_group": "bank_holidays",
+            },
+            handler_bank_holidays_admin: {
+                "resource_group": "bank_holidays/admin",
+            },
             handler_splk_flx_user: {
                 "resource_group": "splk_flx",
             },
