@@ -460,8 +460,8 @@ class TrackMeElasticExecutor(GeneratingCommand):
                     else:
                         # if the search is a raw search but doesn't start with the search keyword, fix this automatically
                         if not re.search(
-                            "^search\s", elastic_report_root_search
-                        ) and not re.search("^\s{0,}\|", elastic_report_root_search):
+                            r"^search\s", elastic_report_root_search
+                        ) and not re.search(r"^\s{0,}\|", elastic_report_root_search):
                             elastic_report_root_search = (
                                 f"search {elastic_report_root_search}"
                             )
