@@ -93,11 +93,21 @@ class SplkOutliersTrain(GeneratingCommand):
     object = Option(
         doc="""
         **Syntax:** **object=****
-        **Description:** The value for object.""",
-        require=True,
+        **Description:** Optional, The value for object.""",
+        require=False,
+        default="*",
         validate=validators.Match("object", r"^.*$"),
     )
 
+    object_id = Option(
+        doc="""
+        **Syntax:** **object_id=****
+        **Description:** Optional, The value for object id.""",
+        require=False,
+        default="*",
+        validate=validators.Match("object_id", r"^.*$"),
+    )
+
     model_id = Option(
         doc="""
         **Syntax:** **model_id=****
@@ -124,6 +134,19 @@ class SplkOutliersTrain(GeneratingCommand):
         validate=validators.Match("model_json_def", r"^.*$"),
     )
 
+    def _get_log_object_ref(self):
+        """Helper function to get object reference for logging (includes object_id when available)."""
+        object_id_ref = f'object_id="{self.object_id}"' if self.object_id != "*" else ""
+        object_ref = f'object="{self.object}"' if self.object != "*" else ""
+        if object_id_ref and object_ref:
+            return f'{object_id_ref}, {object_ref}'
+        elif object_id_ref:
+            return object_id_ref
+        elif object_ref:
+            return object_ref
+        else:
+            return 'object="*"'
+
     def update_kvrecord(
         self,
         collection_rule,
@@ -261,11 +284,26 @@ class SplkOutliersTrain(GeneratingCommand):
         # Get the Outliers rules
         #
 
+        # Validate that at least one of object or object_id is provided
+        if self.object == "*" and self.object_id == "*":
+            error_msg = f'tenant_id="{self.tenant_id}", component="{self.component}", At least one of "object" or "object_id" must be provided.'
+            logging.error(error_msg)
+            raise Exception(error_msg)
+
         # Define the KV query
-        query_string_filter = {
-            "object_category": f"splk-{self.component}",
-            "object": self.object,
-        }
+        # object_id takes precedence over object when both are provided
+        if self.object_id != "*":
+            # Use object_id first (preferred method)
+            query_string_filter = {
+                "object_category": f"splk-{self.component}",
+                "_key": self.object_id,
+            }
+        elif self.object != "*":
+            # Fall back to object if object_id is not provided
+            query_string_filter = {
+                "object_category": f"splk-{self.component}",
+                "object": self.object,
+            }
 
         query_string = {"$and": [query_string_filter]}
 
@@ -286,13 +324,22 @@ class SplkOutliersTrain(GeneratingCommand):
 
         # if no records
         if not key:
-            msg = f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}" outliers rules record cannot be found or are not yet available for this entity.'
+            object_ref = f'object="{self.object}"' if self.object != "*" else f'object_id="{self.object_id}"'
+            msg = f'tenant_id="{self.tenant_id}", component="{self.component}", {object_ref} outliers rules record cannot be found or are not yet available for this entity.'
             logging.error(msg)
             raise Exception(msg)
 
         # log debug
         logging.debug(f'record_outliers_rules="{record_outliers_rules}"')
 
+        # If object_id was used, extract object from the record for use in subsequent code
+        if self.object == "*" and self.object_id != "*":
+            object_from_record = record_outliers_rules.get("object")
+            if object_from_record:
+                # Update self.object so it can be used throughout the code
+                self.object = object_from_record
+                logging.debug(f'Extracted object="{object_from_record}" from record using object_id="{self.object_id}"')
+
         # Get the JSON outliers rules object
         entities_outliers = record_outliers_rules.get("entities_outliers")
 
@@ -365,7 +412,7 @@ class SplkOutliersTrain(GeneratingCommand):
                 """
             )
             logging.info(
-                f"tenant_id={self.tenant_id}, component={self.component}, object={self.object}, ML confidence inspection"
+                f"tenant_id={self.tenant_id}, component={self.component}, {self._get_log_object_ref()}, ML confidence inspection"
             )
 
             # run search
@@ -387,13 +434,13 @@ class SplkOutliersTrain(GeneratingCommand):
                     if isinstance(item, dict):
                         # log
                         logging.info(
-                            f'tenant_id={self.tenant_id}, object={self.object}, ML confidence inspection, ml_confidence={item.get("confidence")}, metrics_duration={item.get("metrics_duration")}, ml_confidence_search={ml_confidence_search}'
+                            f'tenant_id={self.tenant_id}, {self._get_log_object_ref()}, ML confidence inspection, ml_confidence={item.get("confidence")}, metrics_duration={item.get("metrics_duration")}, ml_confidence_search={ml_confidence_search}'
                         )
                         ml_confidence = item.get("confidence", "low")
                         ml_metrics_duration = item.get("metrics_duration", "unknown")
 
             except Exception as e:
-                msg = f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", Machine Learning model training search failed with exception="{str(e)}", run_time="{str(time.time() - start)}"'
+                msg = f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, Machine Learning model training search failed with exception="{str(e)}", run_time="{str(time.time() - start)}"'
                 logging.error(msg)
                 raise Exception(msg)
 
@@ -466,13 +513,17 @@ class SplkOutliersTrain(GeneratingCommand):
 
                         post_data = {
                             "tenant_id": self.tenant_id,
-                            "object": self.object,
                             "component": self.component,
                             "mode": self.mode,
                             "entity_outlier": entity_outlier,
                             "entity_outlier_dict": entity_outlier_dict,
                             "model_json_def": self.model_json_def,
                         }
+                        # Prefer object_id if available, otherwise fall back to object
+                        if self.object_id != "*":
+                            post_data["object_id"] = self.object_id
+                        elif self.object != "*":
+                            post_data["object"] = self.object
 
                         logging.debug(f'post_data="{json.dumps(post_data, indent=2)}"')
 
@@ -486,17 +537,17 @@ class SplkOutliersTrain(GeneratingCommand):
                             )
                             if response.status_code not in (200, 201, 204):
                                 logging.error(
-                                    f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", failure to process ML model training, url="{rest_url}", data="{json.dumps(post_data, indent=0)}", response.status_code="{response.status_code}", response.text="{response.text}"'
+                                    f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, failure to process ML model training, url="{rest_url}", data="{json.dumps(post_data, indent=0)}", response.status_code="{response.status_code}", response.text="{response.text}"'
                                 )
                             else:
                                 logging.info(
-                                    f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", action="success", url="{rest_url}", ML model training processed successfully, response.status_code="{response.status_code}", response="{json.dumps(response.json(), indent=2)}"'
+                                    f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, action="success", url="{rest_url}", ML model training processed successfully, response.status_code="{response.status_code}", response="{json.dumps(response.json(), indent=2)}"'
                                 )
                                 response_json = response.json()
 
                         except Exception as e:
                             logging.error(
-                                f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", ML model traning failed to processed with exception: "{str(e)}"'
+                                f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, ML model traning failed to processed with exception: "{str(e)}"'
                             )
 
                         logging.debug(
@@ -580,16 +631,16 @@ class SplkOutliersTrain(GeneratingCommand):
 
                 # log final
                 logging.info(
-                    f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", Machine Learning model training search terminated, run_time="{round(time.time() - global_start, 3)}"'
+                    f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, Machine Learning model training search terminated, run_time="{round(time.time() - global_start, 3)}"'
                 )
 
             else:
                 if self.model_id:
-                    error_msg = f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", The model_id="{self.model_id}" was not found for this object, available models="{json.dumps(entity_outliers_models)}"'
+                    error_msg = f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, The model_id="{self.model_id}" was not found for this object, available models="{json.dumps(entity_outliers_models)}"'
                     logging.error(error_msg)
                     raise Exception(error_msg)
                 else:
-                    msg = f'tenant_id="{self.tenant_id}", component="{self.component}", object="{self.object}", there are no models yet to be trained for this object.'
+                    msg = f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref()}, there are no models yet to be trained for this object.'
                     logging.info(msg)
                     yield {
                         "_time": time.time(),
