@@ -578,7 +578,7 @@ class SplkWlkGetReportsDef(StreamingCommand):
             search_string = f"""\
                 search index=_internal sourcetype=splunkd_ui_access splunkd servicesNS "saved/searches" method=POST {self.filters_get_last_updates}
                 | regex uri="/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/[^/ ]*$" 
-                | rex field=uri "/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/(?<search_encoded>[^/\? ]*)" 
+                | rex field=uri "/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/(?<search_encoded>[^/\\? ]*)" 
                 | eval savedsearch_name=urldecode(search_encoded) 
                 | rename user as user 
                 | fields _time savedsearch_name user
