@@ -242,7 +242,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         splk_fqm_metrics_report = remove_leading_spaces(
             f"""\
                 | mstats latest(_value) as latest_value, avg(_value) as avg_value, max(_value) as max_value, perc95(_value) as perc95_value, stdev(_value) as stdev_value where `trackme_metrics_idx({tenant_id})` metric_name=* tenant_id="{tenant_id}" object_category="splk-fqm" object_id="{entity_info["_key"]}" by index, object, metric_name
-                | foreach *_value [ eval <<FIELD>> = if(match(metric_name, "\.status"), round('<<FIELD>>', 0), round('<<FIELD>>', 3)) ]
+                | foreach *_value [ eval <<FIELD>> = if(match(metric_name, "\\.status"), round('<<FIELD>>', 0), round('<<FIELD>>', 3)) ]
             """
         )
 
@@ -259,7 +259,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
                 | mcatalog values(metric_name) as metrics where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-fqm" object_id="{entity_info["_key"]}" metric_name=*
                 | mvexpand metrics
                 | rename metrics as metric_name
-                | rex field=metric_name "^trackme\.splk\.fqm\.(?<label>.*)"
+                | rex field=metric_name "^trackme\\.splk\\.fqm\\.(?<label>.*)"
                 | eval order=if(metric_name=="trackme.splk.fqm.status", 0, 1)
                 | sort 0 order
                 | fields - order
